Module
======

.. currentmodule:: pystow.impl

.. autoclass:: Module
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Module.dump_df
      ~Module.dump_json
      ~Module.dump_pickle
      ~Module.ensure
      ~Module.ensure_csv
      ~Module.ensure_excel
      ~Module.ensure_from_google
      ~Module.ensure_from_s3
      ~Module.ensure_json
      ~Module.ensure_open
      ~Module.ensure_open_gz
      ~Module.ensure_open_lzma
      ~Module.ensure_open_tarfile
      ~Module.ensure_open_zip
      ~Module.ensure_pickle
      ~Module.ensure_rdf
      ~Module.ensure_tar_df
      ~Module.ensure_tar_xml
      ~Module.ensure_untar
      ~Module.ensure_zip_df
      ~Module.ensure_zip_np
      ~Module.from_key
      ~Module.join
      ~Module.joinpath_sqlite
      ~Module.load_df
      ~Module.load_json
      ~Module.load_pickle
      ~Module.module
      ~Module.open
      ~Module.submodule

   .. rubric:: Methods Documentation

   .. automethod:: dump_df
   .. automethod:: dump_json
   .. automethod:: dump_pickle
   .. automethod:: ensure
   .. automethod:: ensure_csv
   .. automethod:: ensure_excel
   .. automethod:: ensure_from_google
   .. automethod:: ensure_from_s3
   .. automethod:: ensure_json
   .. automethod:: ensure_open
   .. automethod:: ensure_open_gz
   .. automethod:: ensure_open_lzma
   .. automethod:: ensure_open_tarfile
   .. automethod:: ensure_open_zip
   .. automethod:: ensure_pickle
   .. automethod:: ensure_rdf
   .. automethod:: ensure_tar_df
   .. automethod:: ensure_tar_xml
   .. automethod:: ensure_untar
   .. automethod:: ensure_zip_df
   .. automethod:: ensure_zip_np
   .. automethod:: from_key
   .. automethod:: join
   .. automethod:: joinpath_sqlite
   .. automethod:: load_df
   .. automethod:: load_json
   .. automethod:: load_pickle
   .. automethod:: module
   .. automethod:: open
   .. automethod:: submodule
